@@ -2,6 +2,8 @@ from pathlib import Path
 
 from menagerie.Items.Managers.AbstractManager import AbstractManager
 from menagerie.Items.Meta.JSONMetaItem import JSONMetaItem
+from menagerie.Items.Meta.JSMetaItem import JSMetaScript
+from menagerie.Items.Meta.CSSMetaItem import CSSMetaItem
 from menagerie.Items.Meta.MetaItem import MetaItem
 from menagerie.Items.Meta.XMLMetaItem import XMLMetaItem
 
@@ -18,6 +20,9 @@ class MetaManager(AbstractManager):
             XMLMetaItem(self, Path('sitemap.jinja2'), 'xml'),
             XMLMetaItem(self, Path('browserconfig.jinja2'), 'xml'),
             JSONMetaItem(self, Path('manifest.jinja2'), 'webmanifest'),
+            JSMetaScript(self, Path('base.js'), 'min.js'),
+            JSMetaScript(self, Path('schema.js'), 'min.js'),
+            CSSMetaItem(self, Path('schema.css'), 'min.css'),
             MetaItem(self, Path('robots.jinja2'), 'txt'),
         )
 
