@@ -41,6 +41,14 @@ class NavItem:
         if self.is_folder:
             self.titles = [str(p.meta['title']).lower() for p in self.content]
 
+    def as_dict(self) -> dict[str, object]:
+        return {
+            'is_folder': self.is_folder,
+            'titles': self.titles,
+            'meta': self.meta,
+            'content': self.content if self.is_folder is False else [item.as_dict() for item in self.content]
+            }
+
 
 class PageManager(AbstractManager):
     root_dir = 'pages'
@@ -109,6 +117,9 @@ class PageManager(AbstractManager):
 
     def generate(self):
         self.gen.settings['out_dir'].mkdir(parents=True, exist_ok=True)
+        nav_items = self.generate_nav_items()
+        if self.gen.settings['cache_enabled']:
+            self.gen.cache.check_for_meta_change(nav_items)
         filters = {
             'route': self.route,
             'static': self.gen.shared_info['static_filter'],
@@ -116,7 +127,7 @@ class PageManager(AbstractManager):
             'simple_md': lambda md: self.filter_md.convert(md)
         }
         da_globals = {
-            'nav_items': self.generate_nav_items(),
+            'nav_items': nav_items,
         }
         self.base_env.filters.update(filters)
         self.base_env.globals.update(da_globals)
