@@ -4,7 +4,7 @@ from pathlib import Path
 from menagerie.generate import generate
 from menagerie.new_project import new_project
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 
 def get_parser():
@@ -22,6 +22,7 @@ def get_parser():
     gen_parser = subparsers.add_parser('generate', help="Generate an existing menagerie site")
     gen_parser.add_argument("-c", "--config", help="Specify a different config file to use", default="config.json",
                             type=Path)
+    gen_parser.add_argument("--clear-cache", action="store_true", help="Clear the cache before generating")
 
     return parser
 
@@ -33,6 +34,6 @@ def execute_from_commandline(args: list[str] = None):
     else:
         parsed_args = parser.parse_args(args)
     if parsed_args.command == 'generate':
-        generate(Path(parsed_args.config))
+        generate(Path(parsed_args.config), parsed_args.clear_cache)
     elif parsed_args.command == 'new-project':
         new_project(parsed_args.name)
